# -*- coding:utf-8 -*- 
import codecs
import os

__version__ = '1.0.0'
__author__ = 'tushare'

os.environ.setdefault('PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION', 'python')



"""
for  fz api
"""
from .data_pro import (pro_api, pro_bar)
from .upass import (get_token, set_token)



# !/usr/bin/env python
# -*- coding: utf-8 -*-

"""
方正证券量化数据API接口 
Created on 2020/06/20
@author: Tushare
@group : https://tushare.pro
"""

import pandas as pd
import json
from functools import partial
import requests
from .util.protobuf.funcs import protobuf_parse


class DataApi:

    __token = ''
    __http_url = 'http://datacubeapi.foundersc.com'

    def __init__(self, token, timeout=50):
        """
        Parameters
        ----------
        token: str
            API接口TOKEN，用于用户认证
        """
        self.__token = token
        self.__timeout = timeout

    def query(self, api_name, fields='', **kwargs):
        req_params = {
            'api_name': api_name,
            'token': self.__token,
            'params': kwargs,
            'fields': fields
        }

        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout, headers={
            'Connection': 'close',
            'Accept': 'application/x-protobuf'
        })
        if res.status_code != 200:
            raise Exception(res.content)
        if 'application/x-protobuf' in res.headers['content-type']:
            result = protobuf_parse(res.content)
            if result['code'] != 0:
                raise Exception(result['msg'])
            df = result['data']

        else:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result.get('data')
            if data:
                columns = data['fields']
                items = data['items']
                df = pd.DataFrame(items, columns=columns)
            else:
                df = pd.DataFrame()
        return df

    def __getattr__(self, name):
        return partial(self.query, name)



from setuptools import setup, find_packages
import codecs
import os


def read(fname):
    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()


long_desc = """
PingAn API 
===============

pingan stock data api

"""


setup(
    name='dcube',
    version='1.0.2',
    description='stock data',

    # 程序的详细描述
    long_description=long_desc,
    url='https://datacube.foundersc.com/',
    keywords='Financial Data',

    # 程序的所属分类列表
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: BSD License'
    ],

    # 需要处理的包目录（包含__init__.py的文件夹）
    packages=['dcube', 'dcube/util', 'dcube/util/protobuf'],

    # 需要安装的依赖
    install_requires=[
        'requests>=2.0.0',
        'pandas>=0.16.0',
        'protobuf'
    ],
    include_package_data=True,
)
